@@ -65,6 +65,7 @@ _EXISTING_PASSWORDS = {
     'KeystoneFernetKey1': 'AueoL37kd6eLjV29AG-Ruxu5szW47osgXx6aPOqtI6I=',
     'CephClusterFSID': u'97c16f44-b62c-11e6-aed3-185e0f73fdc5',
     'Ec2ApiPassword': 'FPvz2WiWxrHVWrmSSvv44bqmr',
+    'EtcdInitialClusterToken': 'fcVZXehsSc2KdmFFMKDudxTLKa',
     'PacemakerRemoteAuthkey':
         'bCfHQx4fX7FqENVBbDfBnKvf6FTH6mPfVdNjfzakEjuF4UbmZJHAxWdheEr6feEyZmtM'
         'XEd4w3qM8nMVrzjnDCmqAFDmMDQfKcuNgTnqGnkbVUDGpym67Ry4vNCPHyp9tGGyfjNX'
@@ -127,6 +128,10 @@ _EXISTING_PASSWORDS = {
         'QttkuxyeQTgHupKNaZF6y7rDyf7mbNR9DaPXpBQuZ7un6KDj2Dfh7yvfhPk8cHG7n9pb'
         'KEKD3sgbbKnQ8d9MsGhUtCQVed7dtjpYKsmGJmbYMvZjpGpqsfsHQfFRdCgJHnW3FdQ6'
         'sGhUtCQVed7dtj12',
+    'MigrationSshKey': {
+        'private_key': 'private_key',
+        'public_key': 'public_key'
+        },
 }
 
 
@@ -322,6 +327,8 @@ class GeneratePasswordsActionTest(base.TestCase):
 
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
                 'get_orchestration_client')
+    @mock.patch('tripleo_common.utils.passwords.'
+                'create_ssh_keypair')
     @mock.patch('tripleo_common.utils.passwords.'
                 'get_snmpd_readonly_user_password')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
@@ -329,9 +336,12 @@ class GeneratePasswordsActionTest(base.TestCase):
     @mock.patch('mistral.context.ctx')
     def test_run_passwords_exist(self, mock_ctx, mock_get_workflow_client,
                                  mock_get_snmpd_readonly_user_password,
+                                 mock_create_ssh_keypair,
                                  mock_get_orchestration_client):
 
         mock_get_snmpd_readonly_user_password.return_value = "TestPassword"
+        mock_create_ssh_keypair.return_value = {'public_key': 'Foo',
+                                                'private_key': 'Bar'}
 
         mock_ctx.return_value = mock.MagicMock()
         mock_mistral = mock.MagicMock()
@@ -360,6 +370,8 @@ class GeneratePasswordsActionTest(base.TestCase):
 
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
                 'get_orchestration_client')
+    @mock.patch('tripleo_common.utils.passwords.'
+                'create_ssh_keypair')
     @mock.patch('tripleo_common.utils.passwords.'
                 'get_snmpd_readonly_user_password')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
@@ -367,9 +379,12 @@ class GeneratePasswordsActionTest(base.TestCase):
     @mock.patch('mistral.context.ctx')
     def test_passwords_exist_in_heat(self, mock_ctx, mock_get_workflow_client,
                                      mock_get_snmpd_readonly_user_password,
+                                     mock_create_ssh_keypair,
                                      mock_get_orchestration_client):
 
         mock_get_snmpd_readonly_user_password.return_value = "TestPassword"
+        mock_create_ssh_keypair.return_value = {'public_key': 'Foo',
+                                                'private_key': 'Bar'}
 
         existing_passwords = _EXISTING_PASSWORDS.copy()
         existing_passwords.pop("AdminPassword")
