@@ -182,66 +182,6 @@ class FindNodeHandlerTest(base.TestCase):
                           nodes._find_node_handler, {'pm_type': 'foobar'})
 
 
-class NodeProvisionStateTest(base.TestCase):
-
-    def test_wait_for_provision_state(self):
-        baremetal_client = mock.Mock()
-        baremetal_client.node.get.return_value = mock.Mock(
-            provision_state="available", last_error=None)
-        nodes.wait_for_provision_state(baremetal_client, 'UUID', "available")
-
-    def test_wait_for_provision_state_not_found(self):
-        baremetal_client = mock.Mock()
-        baremetal_client.node.get.side_effect = exception.InvalidNode("boom")
-        self.assertRaises(
-            exception.InvalidNode,
-            nodes.wait_for_provision_state,
-            baremetal_client, 'UUID', "enroll")
-
-    def test_wait_for_provision_state_timeout(self):
-        baremetal_client = mock.Mock()
-        baremetal_client.node.get.return_value = mock.Mock(
-            provision_state="not what we want", last_error=None)
-        self.assertRaises(
-            exception.Timeout,
-            nodes.wait_for_provision_state,
-            baremetal_client, 'UUID', "available", loops=1, sleep=0.01)
-
-    def test_wait_for_provision_state_fail(self):
-        baremetal_client = mock.Mock()
-        baremetal_client.node.get.return_value = mock.Mock(
-            provision_state="enroll",
-            last_error="node on fire; returning to previous state.")
-        self.assertRaises(
-            exception.StateTransitionFailed,
-            nodes.wait_for_provision_state,
-            baremetal_client, 'UUID', "available", loops=1, sleep=0.01)
-
-    @mock.patch('tripleo_common.utils.nodes.wait_for_provision_state')
-    def test_set_nodes_state(self, wait_for_state_mock):
-
-        wait_for_state_mock.return_value = True
-        bm_client = mock.Mock()
-
-        # One node already deployed, one in the manageable state after
-        # introspection.
-        node_list = [
-            mock.Mock(uuid="ABCDEFGH", provision_state="active"),
-            mock.Mock(uuid="IJKLMNOP", provision_state="manageable")
-        ]
-
-        skipped_states = ('active', 'available')
-        affected_nodes = nodes.set_nodes_state(bm_client, node_list, 'provide',
-                                               'available', skipped_states)
-        uuids = [node.uuid for node in affected_nodes]
-
-        bm_client.node.set_provision_state.assert_has_calls([
-            mock.call('IJKLMNOP', 'provide'),
-        ])
-
-        self.assertEqual(uuids, ['IJKLMNOP', ])
-
-
 class NodesTest(base.TestCase):
 
     def _get_node(self):
@@ -569,6 +509,38 @@ class NodesTest(base.TestCase):
             driver_info={'ucs_password': 'random', 'ucs_address': 'foo.bar',
                          'ucs_username': 'test'})
 
+    def test_register_ironic_node_pxe_ipmitool(self):
+        node_properties = {"cpus": "1",
+                           "memory_mb": "2048",
+                           "local_gb": "30",
+                           "cpu_arch": "amd64",
+                           "capabilities": "num_nics:6"}
+        node = self._get_node()
+        node['pm_type'] = 'pxe_ipmitool'
+        node['pm_port'] = '6230'
+        client = mock.MagicMock()
+        nodes.register_ironic_node(node, client=client)
+        client.node.create.assert_called_once_with(
+            driver='pxe_ipmitool', name='node1', properties=node_properties,
+            driver_info={'ipmi_password': 'random', 'ipmi_address': 'foo.bar',
+                         'ipmi_username': 'test', 'ipmi_port': '6230'})
+
+    def test_register_ironic_node_pxe_drac(self):
+        node_properties = {"cpus": "1",
+                           "memory_mb": "2048",
+                           "local_gb": "30",
+                           "cpu_arch": "amd64",
+                           "capabilities": "num_nics:6"}
+        node = self._get_node()
+        node['pm_type'] = 'pxe_drac'
+        node['pm_port'] = '6230'
+        client = mock.MagicMock()
+        nodes.register_ironic_node(node, client=client)
+        client.node.create.assert_called_once_with(
+            driver='pxe_drac', name='node1', properties=node_properties,
+            driver_info={'drac_password': 'random', 'drac_host': 'foo.bar',
+                         'drac_username': 'test', 'drac_port': '6230'})
+
     def test_register_ironic_node_update_int_values(self):
         node = self._get_node()
         ironic = mock.MagicMock()
